<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="zh" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>分类：</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>开始 Torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>跳过哈希检查</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>创建子文件夹</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrent 管理模式：</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>未分类</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>添加分类...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>移除分类</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>移除未使用的分类</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>继续 torrents</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>暂停 torrents</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>删除 torrents</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>新建类别</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>编辑类别...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>退出 qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>每行一个连接</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>全局上传速度限制必须大于 0 或禁用。</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>全局下载速度限制必须大于 0 或禁用。</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>备用上传速度限制必须大于 0 或禁用。</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>备用下载速度限制必须大于 0 或禁用。</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>最大同时下载数必须大于 -1。</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>最大同时上传数必须大于 -1。</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>最大同时活动 torrents 必须大于 -1。</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>最大连接数限制必须大于 0 或禁用。</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>每个 torrent 的最大连接数限制必须大于 0 或禁用。</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>每个 torrent 的最大上传线程数限制必须大于 0 或禁用。</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>无法保存程序偏好选项，可能是无法连接到 qBttorrent。</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent on Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>分享率限制必须在 0 和 9998 之间。</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>做种时间限制必须在 0 和 525600 分钟之间。</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>用于传入连接的端口必须大于 1 且小于 65535。</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>用于 Web 用户界面的端口必须大于 1 且小于 65535。</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>登录失败，可能是无法连接到 qBttorrent。</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>无效的用户名或密码。</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登录</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>原作者</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>上传 Torrents</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>保存文件到：</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie：</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>在此输入文件夹名称</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>更多信息</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>证书信息</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>更改保存位置</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>限制上传速率</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>限制下载速率</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>重命名 torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>其他...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>周一</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>周二</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>周三</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>周四</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>周五</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>周六</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>周日</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>从 URL 或磁力链接下载 Torrents</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>上传本地的 torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>你确定要从传输列表中删除选中的 torrents 吗？</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>无法访问 qBittorrent 客户端</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>全局上传种子数量限制必须大于 0 或禁用。</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>无效的分类名：\n在分类名中请不要使用特殊字符。</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>无法创建分类</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>上传速率阈值必须大于0。</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>剩余磁盘空间: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Torrent 不活动时间必须大于0。</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>保存管理</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>下载速率阈值必须大于0。</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent已经关闭。</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>View</source>
        <translation>视图</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>选项...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>最低优先级</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>最高优先级</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>降低优先级</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>提升优先级</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>顶部工具栏</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>状态栏</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>在标题栏显示速度</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>捐赠</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>重新开始所有任务</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>统计</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>暂停所有任务</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>添加 Torrent 文件...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>帮助文档</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>添加 Torrent 链接...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>全局上传速度限制</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>全局下载速度限制</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>您确定要退出 qBittorrent 吗？</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1, U: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>备用速率限制</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>搜索引擎</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>过滤 Torrent 列表</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>传输</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web 用户界面</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>语言</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>用户界面语言：</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>下载完成时发送电子邮件通知</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Torrent 完成时运行外部程序</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP 过滤</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>计划备用速度限制的启用时间</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrent 排队</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>分享 torrents 直至达到做种时间限制</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>自动添加以下 trackers 到新的 torrents：</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Web 用户界面（远程控制）</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP 地址:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>服务器域名：</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>使用 HTTPS 而不是 HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>对本地主机上的客户端跳过身份验证</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>对 IP 子网白名单中的客户端跳过身份验证</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>更新我的动态域名</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>保存未完成的 torrents 到：</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>复制 .torrent 文件到：</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>复制下载完成的 .torrent 文件到：</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>为所有文件预分配磁盘空间</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>为不完整的文件添加扩展名 .!qB</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>自动从此处添加 torrents：</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP 服务器：</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>该服务器需要安全链接（SSL）</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>验证</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>启用的协议:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP 和 μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>监听端口</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>用于传入连接的端口：</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>使用我的路由器的 UPnP / NAT-PMP 端口转发</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>在每次启动时使用不同的端口</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>连接限制</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>每 torrent 最大连接数：</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>全局最大连接数：</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>每 torrent 上传线程最大值：</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>全局最大上传线程数：</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>代理服务器</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(无)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>主机：</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>端口：</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>使用代理服务器进行连接</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>禁用代理服务器不支持的连接</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>只对 torrents 使用代理</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>过滤规则路径 (.dat, .p2p, .p2b)：</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>手动屏蔽 IP 地址...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>匹配 trackers</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>全局速度限制</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>上传：</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>下载：</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>备用速度限制</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>从：</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>到：</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>时间：</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>每天</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>工作日</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>周末</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>设置速度限制</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>对传送总开销进行速度限制</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>对 µTP 协议进行速度限制</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>隐私</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>启用 DHT（分散网络）以获取更多资源</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>启用用户交换（PeX）以获取更多资源</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>启用本地资源搜索以获取更多资源</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>加密模式：</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>偏好加密</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>强制加密</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>禁用加密</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>启用匿名模式</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>最大活动的下载数：</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>最大活动的上传数：</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>最大活动的 torrents 数：</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>慢速 torrent 不计入限制内</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>分享率限制</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>分享 torrents 直至达到比率</translation>
    </message>
    <message>
        <source>then</source>
        <translation>然后</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>暂停它们</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>移除它们</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>使用我的路由器的 UPnP / NAT-PMP 端口来转发</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>证书：</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>密钥：</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>注册</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>域名：</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>支持的参数（区分大小写）：</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N：Torrent 名称</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L：分类</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: 标签 （用逗号分隔）</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F：内容路径（与多文件 torrent 的根目录相同）</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R：根目录（第一个 torrent 的子目录路径）</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D：保存路径</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C：文件数</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z：Torrent 大小（字节）</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T：当前 tracker</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I：哈希值</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>提示：使用引号将参数扩起以防止文本被空白符分割（例如："%N"）</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Web 用户界面用户名长度最少为 3 个字符。</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Web 用户界面密码长度最少为 6 个字符。</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分钟</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>启用“点击劫持”保护</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>启用跨站点请求伪造(CSRF)保护</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>完成后删除 .torrent 文件</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>下载速度阈值：</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>上传速度阈值：</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>修改当前密码</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>使用备用 Web UI</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>默认保存路径：</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>替代的Web UI文件位置不能为空。</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>不要自动开始下载</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>切换 Torrent 到手动模式</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>当 Torrent 分类修改时：</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>重新定位受影响的 Torrent</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>限制本地用户带宽</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 为无限制</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>重新定位 Torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>当默认保存路径修改时：</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>启用主机标头验证</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>验证</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>当分类保存路径修改时：</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>创建多文件子目录</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>将受影响的种子切换到手动模式</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>文件路径：</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>种子不活动时间</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>默认种子管理模式</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>当添加种子时</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>标志</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>客户端</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>进度</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>下载速度</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>上传速度</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>已下载</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>已上传</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>文件关联</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>文件</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>国家</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>正常</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>较高</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>最高</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>普通</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>用户</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP 源</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>内容</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>已下载：</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>传输</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>活动时间：</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>剩余时间：</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>已上传：</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>种子：</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>下载速度：</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>上传速度：</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>用户：</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>下载限制：</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>上传限制：</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>已丢弃：</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>连接：</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>注释：</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>分享率：</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>重新发布于：</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>最后完整可见：</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>总大小：</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>区块：</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>创建：</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>添加于：</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>完成于：</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>创建于：</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent 哈希值：</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>保存路径：</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>从不</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (已完成 %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (本次会话 %2)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (最大 %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (总计 %2)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (平均 %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>下载限制：</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>上传限制：</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>监控文件夹</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>覆盖保存位置</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>监控文件夹</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>默认保存位置</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>统计</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>用户统计</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>缓存统计</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>读缓存次数：</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>在队列的平均时间：</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>连接用户：</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>历史分享率：</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>历史下载：</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>本次对话丢弃：</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>历史上传：</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>总缓冲大小：</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>性能统计</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>队列的 I/O 任务：</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>写入缓存超负荷：</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>读取缓存超负荷：</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>总队列大小：</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT：%1 结点</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>全部 (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>下载 (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>做种 (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>完成 (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>进行中 (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>暂停 (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>活动 (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>非活动 (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>错误 (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>全部 (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>下载 (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>做种 (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>完成 (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>暂停 (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>进行中 (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>活动 (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>非活动 (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>错误 (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>进度</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>下载优先级</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>剩余</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>可用性</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>名称</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>选定大小</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>已完成</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>状态</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>种子</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>用户</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>下载速度</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>上传速度</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>比率</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>剩余时间</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>分类</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>添加于</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>完成于</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>下载限制</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>上传限制</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>已下载</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>已上传</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>本次会话下载</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>本次会话上传</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>剩余</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>有效时间</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>保存路径</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>完成</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>比率限制</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>最后完整可见</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>最后活动</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>总大小</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>用户</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>消息</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Tracker：</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>更新...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>工作</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>禁用</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>还未联系</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>种子</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>未工作</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>复制 Tracker</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>新增 Tracker</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>编辑 Tracker</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Tracker 编辑</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>吸血者</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>移除 Tracker</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>添加 trackers 对话窗</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>要添加的 trackers 列表（每行一个）：</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 前</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>配置</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>移动</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] 做种</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>做种</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>队列</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] 下载</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>下载元数据</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>校验</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>丢失文件</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>列队校验</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>校验恢复数据</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>等待</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>分类</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torrent 下载速度限制</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torrent 上传速度限制</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>继续</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>强制继续</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>删除</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>限制分享率...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>限制上传速度...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>限制下载速度...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>上移</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>下移</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>移至顶部</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>移至底部</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>更改保存位置...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>复制文件名</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>复制哈希值</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>先下载首尾段</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>自动 Torrent 管理</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>分类</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>新分类...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>重置</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>优先</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>强制再次核对</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>复制磁力链接</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>超级做种模式</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>重命名...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>以连续顺序下载</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>重新校验</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>新分类</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>路径</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>新名称</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>更改保存位置</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>强制重新汇报</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>编辑类别...</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>保存路径</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torrent 上传/下载率限制</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>使用全局分享限制</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>设置为无分享限制</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>设置分享限制为</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>比率</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>时间</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>一个使用 C++ 编写的基于 Qt toolkit 和 libtorrent-rasterbar 的高级 BitTorrent 客户端</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>主页：</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>论坛：</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Bug 跟踪：</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>确认删除</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>同时从硬盘上删除文件</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>确认删除 - qBttorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>从 URL 下载</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>添加 Torrent 链接...</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 小时 %2 分钟</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 天 %2 小时</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>未知</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 分钟</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 分钟</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>保存路径为空</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>插件路径：</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>网址或本地目录</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>安装插件</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>种子：</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>所有插件</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>搜索插件...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>所有类别</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>在以下范围搜索：</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>复制描述页网址</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>跳至描述页</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>结果 （显示</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>过滤器</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>仅 Torrent 名称</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>只针对开启的</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>缺少</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>任意位置</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>卸载</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>安装新插件</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>你可以在这里获取新的搜索引擎插件：</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>已安装的搜索插件：</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>启用</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>警告：在下载来自这些搜索引擎的 Torrent 时，请确认它符合您所在国家的版权法。</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>检查更新</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>搜索插件</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>吸血者</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>搜索引擎</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>做种</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>网址</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>启用</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
</context>
</TS>